// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: Om2pha
// Author: Richard Saxton 
//
// Description: Main class for producing an OM multi-spectral file
//
// Modifications: See ChangeLog
//

#ifndef Om2pha_H
#define Om2pha_H

/* General classes */
#include <iostream>

/* SAS-specific classes */
#include "Tracer.h"
#include "Dal.h"


/****************************************************
 *
 * class Om2pha
 *
 ***************************************************/

class Om2pha
{
public:

	 // A structure to contain filter information
	 typedef struct {
	           string name;
	           string resp;
	              double crate;
	              double error;
	              double exposure;
	  } filter;

	 typedef std::vector<filter> FilterList;


  /* Constructor */
  Om2pha();

  /* Destructor */
  ~Om2pha();

  /* Methods */

  Om2pha::FilterList getFilterRates(double ra, double dec, string srclist);

    /* Purpose:
                To read the filter rates for given source from source list
       Input:
                ra, dec - celestial position
                srclist - name of the input source list
    */

  void writeMultipleSpecFile(string outputfile, FilterList filterList);

    /* Purpose:
		To write the multiple spectrum output file
       Input:
		outputfile - name of the output file
		filterList - class holding all of the filter values
    */

 void validateSrcListFormat(DataSet * srcSet);

 /* Purpose:
		To check the format of the input source list
      Input:
		srcSet - Pointer to the source list
   */

 int getIndex(double ra, double dec,
		                 vector<double> racorr, vector<double> decorr);

 /* Purpose:
 		To get the index of the entry given by ra, dec
       Input:
 		ra, dec  - required celestial position
    */

 void initFilterNames();

 /* Purpose:
 		set the filtername and the response file names
 	*/

 void addKeys(Table * spectrumtable);

 /* Purpose:
 		add attributes to the output file
 	*/

  private:

  std::vector<string> _filterName, _filterResp;
  double _srcRa; // RA of source found in list
  double _srcDec; // DEC of source found in list

};

#endif

